"""
Name : gm_login_utils.py
Author  : 池泽琴
Contact : 邮箱地址
Time    : 2023-10-07 14:36
Desc:
"""
import hashlib
import json
import time

import requests
from gmmysql.mysqlexe import OperateMysql
from enum import Enum
from urllib3.exceptions import InsecureRequestWarning
import urllib3

urllib3.disable_warnings(InsecureRequestWarning)

class LoginDomain(Enum):
	"""登录域名设置枚举"""
	login_uri = 'djc-gateway/authing/login'
	user_uri = 'gateway/v1/user?requireAvatar=true'
	authing_switch_uri = 'djc-gateway/authing/v1/user'
	# test1配置
	test1_djc = "https://www.djctest1.gm/"
	test1_zcj = 'https://www.cqzcjtest1.gm/'
	test1_xcj = 'https://www.xcjtest1.gm/'
	test1_zdb = 'https://zdb.xcjtest1.gm/'
	# show配置
	show_djc = "https://www.djcshow.gm/"
	show_zcj = 'https://www.gpwbeta.com/'
	show_xcj = 'https://www.cqzcjshow.com/'
	show_zdb = 'https://zdb.cqzcjshow.com/'
	# test2配置
	test2_djc = "https://www.djctest2.gm/"
	test2_zcj = 'https://www.cqzcjtest2.gm/'
	test2_xcj = 'https://www.xcjtest2.gm/'



class LoginData(Enum):
	"""登录头、登录URI等枚举"""
	form_headers = {'content-type': 'application/x-www-form-urlencoded'}
	login_uri = 'djc-gateway/authing/login'
	application_headers = {'Content-type': 'application/json'}

	# 登录时传递form表单的数据定义如下，请根据各环境配置
	zcj_test1_login_data_dict = {
		'origin': 'https://www.cqzcjtest1.gm',
		'password': '402522cea3acc6228192fec58a7b8a79',
		'client_id': 'plat@ZCJ',
		'scope': 'www.cqzcjtest1.gm',
		'options': '',
		'response_type': 'code',
		'redirect_uri': 'https://www.cqzcjtest1.gm/gateway/v1/login',
		'certLoginProvider': 'ezca',
		'success_uri': 'https://www.cqzcjtest1.gm/login-app/login-success/index.html',
		'state': '{"client_id": "plat@ZCJ", "scope": "www.cqzcjtest1.gm", "redirect_uri": "https://www.cqzcjtest1.gm/gateway/v1/login"}'
	}

	xcj_test1_login_data_dict = {
		'origin': 'https://www.xcjtest1.gm',
		'password': '402522cea3acc6228192fec58a7b8a79',
		'client_id': 'plat@ZCJ',
		'scope': 'www.xcjtest1.gm',
		'options': '',
		'response_type': 'code',
		'redirect_uri': 'https://www.xcjtest1.gm/gateway/v1/login',
		'certLoginProvider': 'ezca',
		'success_uri': 'https://www.xcjtest1.gm/login-app/login-success/index.html',
		'state': '{"client_id": "plat@XCJ", "scope": "www.xcjtest1.gm", "redirect_uri": "https://www.xcjtest1.gm/gateway/v1/login"}'
	}

	zcj_show_login_data_dict = {
		'origin': 'https://www.gpwbeta.com',
		'password': '402522cea3acc6228192fec58a7b8a79',
		'client_id': 'plat@ZCJ',
		'scope': 'www.gpwbeta.com',
		'options': '',
		'response_type': 'code',
		'redirect_uri': 'https://www.gpwbeta.com/gateway/v1/login',
		'certLoginProvider': 'ezca',
		'success_uri': 'https://www.gpwbeta.com/login-app/login-success/index.html',
		'state': '{"client_id": "plat@ZCJ", "scope": "www.gpwbeta.com", "redirect_uri": "https://www.gpwbeta.com/gateway/v1/login"}'
	}

	xcj_show_login_data_dict = {
		'origin': 'https://www.cqzcjshow.com',
		'password': '402522cea3acc6228192fec58a7b8a79',
		'client_id': 'plat@XCJ',
		'scope': 'www.cqzcjshow.com',
		'options': '',
		'response_type': 'code',
		'redirect_uri': 'https://www.cqzcjshow.com/gateway/v1/login',
		'certLoginProvider': 'ezca',
		'success_uri': 'https://www.cqzcjshow.com/login-app/login-success/index.html',
		'state': '{"client_id": "plat@XCJ", "scope": "www.cqzcjshow.com", "redirect_uri": "https://www.cqzcjshow.com/gateway/v1/login"}'
	}

def _second_verify(resp, login_org):
	"""第一次验证不通过时获取返回值，并传入待登录的单位名称，返回EMPLOEE"""
	try:
		identities = json.loads(resp.text).get('identities')
		identities_id = [x['id'] for x in identities if x['name'] == str(login_org)][0]
		return identities_id
	except IndexError as e:
		print(f"二次验证未获取到单位名称,请传入单位名称。当前单位名称：{login_org}")

def login_zcj(session, env, user_name, org_name=None):
	"""政采机房登录，需传入session，环境名称env，登录用户账号user_name，登录单位org_name且默认为空"""
	env = env.strip().lower()
	login_data_dict_name = f'zcj_{env}_login_data_dict'  # 根据env参数替换登录data字典
	login_domain = f'{env}_zcj'   # 根据env参数替换环境
	try:
		login_data_dict_copy = getattr(LoginData, login_data_dict_name).value.copy()   # 封装登录data字典
		get_token_url = getattr(LoginDomain, login_domain).value + LoginDomain.login_uri.value  # 组装登录url
		user_info_url = getattr(LoginDomain, login_domain).value + LoginDomain.user_uri.value
		login_data_dict_copy['username'] = user_name  # 根据账号，在data字典中添加username的键值对
		# 登录
		res = session.post(get_token_url, headers=LoginData.form_headers.value, data=login_data_dict_copy, verify=False)
		# 获取登录人基本信息--user接口
		user_info = session.get(user_info_url, verify=False)
		# 账号如有多单位时，无法确定登录身份，需再次选择登录单位
		if res.status_code == 400 and '无法确定登陆身份' in res.text:  # 新登录机制，当返回400或返回有无法确定登陆身份的文本，则走二次验证
			print(f"二次登录机制--当返回400或返回有无法确定登陆身份的文本时，需要指定登录单位。\n"
			      f"当前登录单位是：{org_name}")
			login_data_dict_copy['identityId'] = _second_verify(res, org_name)  # 传入org_name可登录
			res = session.post(get_token_url, headers=LoginData.form_headers.value, data=login_data_dict_copy, verify=False)
			user_info = session.get(user_info_url, verify=False)
			return session  # 返回请求session
		elif res.status_code == 400 and '极验证未通过' in res.text:  # 触发极验证机制
			print(f"本次登录触发极验证机制")
			get_token_url = get_token_url + "?geetest_challenge=111111&geetest_seccode=111111&geetest_validate=111111"
			res = session.post(get_token_url, headers=LoginData.form_headers.value, data=login_data_dict_copy, verify=False)
			print("\n" + "登录结果-Response code是: {}".format(res.status_code))
			return session
		elif res.status_code == 400 and '二次验证' in res.text:  # 触发手机二次验证机制
			print(f"本次登录触发二次验证机制")
			code = "111111"
			check_mobile = json.loads(res.text)["additional"]["mobile"]
			login_data_dict_copy["code"] = code
			login_data_dict_copy["mobile"] = check_mobile
			res = session.post(get_token_url, headers=LoginData.form_headers.value, data=login_data_dict_copy, verify=False)
			print("\n" + "登录结果-Response code是: {}".format(res.status_code))
			return session
		else:
			return session
	except AttributeError:
		raise ValueError(f'Invalid environment: {env}')

def login_xcj(session, env, user_name, org_name=None):
	"""行采机房登录，需传入session，环境名称env，登录用户账号user_name，登录单位org_name且默认为空"""
	env = env.strip().lower()
	login_data_dict_name = f'xcj_{env}_login_data_dict'
	login_domain = f'{env}_xcj'
	try:
		login_data_dict_copy = getattr(LoginData, login_data_dict_name).value.copy()  # 封装登录data字典
		get_token_url = getattr(LoginDomain, login_domain).value + LoginDomain.login_uri.value  # 组装登录url
		user_info_url = getattr(LoginDomain, login_domain).value + LoginDomain.user_uri.value  # 组装用户信息url
		login_data_dict_copy['username'] = user_name
		# 登录
		res = session.post(get_token_url, headers=LoginData.form_headers.value, data=login_data_dict_copy, verify=False)
		# 获取登录人基本信息--user接口
		user_info = session.get(user_info_url, verify=False)
		# 账号如有多单位时，无法确定登录身份，需再次选择登录单位
		if res.status_code == 400 and '无法确定登陆身份' in res.text:  # 新登录机制，当返回400或返回有无法确定登陆身份的文本，则走二次验证
			print(f"二次登录机制--当返回400或返回有无法确定登陆身份的文本时，需要指定登录单位。\n"
			      f"当前登录单位是：{org_name}")
			login_data_dict_copy['identityId'] = _second_verify(res, org_name)  # 传入org_name可登录
			res = session.post(get_token_url, headers=LoginData.form_headers.value, data=login_data_dict_copy, verify=False)
			user_info = session.get(user_info_url, verify=False)
			return session  # 返回请求session
		elif res.status_code == 400 and '极验证未通过' in res.text:
			print(f"本次登录触发极验证机制")
			get_token_url = get_token_url + "?geetest_challenge=111111&geetest_seccode=111111&geetest_validate=111111"
			res = session.post(get_token_url, headers=LoginData.form_headers.value, data=login_data_dict_copy, verify=False)
			print("\n" + "登录结果-Response code是: {}".format(res.status_code))
			return session
		elif res.status_code == 400 and '进行二次验证' in res.text:  # 触发手机二次验证机制
			print(f"本次登录触发二次验证机制")
			code = "111111"
			check_mobile = json.loads(res.text)["additional"]["mobile"]
			login_data_dict_copy["code"] = code
			login_data_dict_copy["mobile"] = check_mobile
			res = session.post(get_token_url, headers=LoginData.form_headers.value, data=login_data_dict_copy, verify=False)
			print("\n" + "登录结果-Response code是: {}".format(res.status_code))
			return session
		else:
			return session
	except AttributeError:
		raise ValueError(f'Invalid environment: {env}')

# 登录后切换身份，例如此账号有供应商、采购单位、财政等多种身份，根据您的需求进行切换；
def switch_login_identity(session, env, orgType):
	"""登录后切换身份，例如此账号有供应商、采购单位、财政等多种身份，根据您的需求进行切换"""
	try:
		env = env.strip().lower()
		login_domain = f'{env}_djc'  # 只需调用djc域名下的接口即可
		switch_user_type_url = getattr(LoginDomain, login_domain).value + LoginDomain.authing_switch_uri.value  # 组装切换登录身份url
		params = {
			"orgType": str(orgType)
		}
		print("开始切换用户登录单位身份类型")
		session.put(switch_user_type_url, headers=LoginData.application_headers.value, params=params, verify=False)
	except Exception as e:
		print(f"切换用户身份错误，请检查，错误信息:{e}")


# 查询当前用户登录的单位类型（1：平台、2：财政；3、采购人、5：供应商、7：金融机构）
def user_login_identity(session, env, host):
	env = env.strip().lower()
	login_domain = f'{env}_{host}'  # show_zcj
	print(login_domain)
	user_uri = getattr(LoginDomain, login_domain).value + LoginDomain.user_uri.value  # 组装获取用户身份url
	print(user_uri)
	response = session.get(user_uri, headers=LoginData.application_headers.value, verify=False)
	return response.text




if __name__ == '__main__':
	session = requests.session()
	# req = login_zcj(session, 'test1', '18502120689', '远大空调有限公司')  # 如果账号属于多个单位，请传入待登录单位名称；
	# req1 = login_xcj(session, 'test1', '13760187099', '大江大河')
	print(LoginData.__doc__)
	# print(user_login_org_type(session, 'test1', 'xcj'))
	switch_login_identity(session, 'test1', '3')



"""
Name : gm_request_utils.py
Author  : 写上自己的名字
Contact : 邮箱地址
Time    : 2023-05-20 13:40
Desc: 封装requests请求方法get、post、put、delete、options、head
"""


import requests


def send_get_request(request, url, headers=None, params=None, data=None, json=None, verify=False):
    response = request.get(url=url, headers=headers, params=params, data=data, json=json,
                               verify=verify)
    return response

def send_post_request(request, url, headers=None, params=None, data=None, json=None, verify=False):
    response = request.post(url=url, headers=headers, params=params, data=data, json=json,
                               verify=verify)
    return response

def send_put_request(request, url, headers=None, params=None, data=None, json=None, verify=False):
    response = request.put(url=url, headers=headers, params=params, data=data, json=json,
                               verify=verify)
    return response

def send_delete_request(request, url, headers=None, params=None, data=None, json=None, verify=False):
    response = request.delete(url=url, headers=headers, params=params, data=data, json=json,
                               verify=verify)
    return response

def send_options_request(request, url, headers=None, params=None, data=None, json=None, verify=False):
    response = request.options(url=url, headers=headers, params=params, data=data, json=json,
                               verify=verify)
    return response

def send_head_request(request, url, headers=None, params=None, data=None, json=None, verify=False ):
    response = request.head(url=url, headers=headers, params=params, data=data, json=json,
                               verify=verify)
    return response



# -*-coding=utf-8-*-
# 生成、验证社会统一社会信用代码

# 统一社会信用代码中不使用I,O,Z,S,V
import random
import json
from pathlib import Path

SOCIAL_CREDIT_CHECK_CODE_DICT = {
    "0": 0,
    "1": 1,
    "2": 2,
    "3": 3,
    "4": 4,
    "5": 5,
    "6": 6,
    "7": 7,
    "8": 8,
    "9": 9,
    "A": 10,
    "B": 11,
    "C": 12,
    "D": 13,
    "E": 14,
    "F": 15,
    "G": 16,
    "H": 17,
    "J": 18,
    "K": 19,
    "L": 20,
    "M": 21,
    "N": 22,
    "P": 23,
    "Q": 24,
    "R": 25,
    "T": 26,
    "U": 27,
    "W": 28,
    "X": 29,
    "Y": 30,
}

# GB11714-1997全国组织机构代码编制规则中代码字符集
ORGANIZATION_CHECK_CODE_DICT = {
    "0": 0,
    "1": 1,
    "2": 2,
    "3": 3,
    "4": 4,
    "5": 5,
    "6": 6,
    "7": 7,
    "8": 8,
    "9": 9,
    "A": 10,
    "B": 11,
    "C": 12,
    "D": 13,
    "E": 14,
    "F": 15,
    "G": 16,
    "H": 17,
    "I": 18,
    "J": 19,
    "K": 20,
    "L": 21,
    "M": 22,
    "N": 23,
    "O": 24,
    "P": 25,
    "Q": 26,
    "R": 27,
    "S": 28,
    "T": 29,
    "U": 30,
    "V": 31,
    "W": 32,
    "X": 33,
    "Y": 34,
    "Z": 35,
}


class CreditIdentifier(object):
    @staticmethod
    def get_random_address():
        with open(Path(__file__).parent / "address.json", encoding='utf-8') as reader:
            address = json.load(reader)
        nums_province = len(address)
        province = address[random.randint(0, nums_province - 1)]
        nums_city = len(province["child"])
        city = province["child"][random.randint(0, nums_city - 1)]
        areas = city["child"]
        nums_area = len(areas)
        area = areas[random.randint(0, nums_area - 1)]
        address_name = f"{province['name']}{city['name']}{area['name']}"
        address_code = area["code"]
        return {"name": address_name, "code": address_code}

    def CreateC9(self, code):
        # 第i位置上的加权因子
        weighting_factor = [3, 7, 9, 10, 5, 8, 4, 2]
        # 第9~17位为主体标识码(组织机构代码)
        organization_code = code[8:17]
        # 本体代码
        ontology_code = organization_code[:8]
        # 生成校验码
        tmp_check_code = self.gen_check_code(
            weighting_factor, ontology_code, 11, ORGANIZATION_CHECK_CODE_DICT
        )
        return code[:16] + tmp_check_code

    def gen_random_credit_code(self):
        """Generate random credit code"""

        department = "9"  # 登记管理部门代码
        agency = "123"  # 机构类别
        organization_num = str(random.randint(11111111, 99999999))

        # 行政区划代码
        address = self.get_random_address()
        credit_code = (
            f"{department}{random.choice(agency)}{address['code']}{organization_num}"
        )
        return {
            "credit-code": self.get_social_credit_code(credit_code),
        }

    def get_social_credit_code(self, code):
        code = self.CreateC9(code[:16])
        # 第i位置上的加权因子
        weighting_factor = [
            1,
            3,
            9,
            27,
            19,
            26,
            16,
            17,
            20,
            29,
            25,
            13,
            8,
            24,
            10,
            30,
            28,
        ]
        # 本体代码
        ontology_code = code[:17]
        # 计算校验码
        tmp_check_code = self.gen_check_code(
            weighting_factor, ontology_code, 31, SOCIAL_CREDIT_CHECK_CODE_DICT
        )
        return code[:17] + tmp_check_code

    # 只返回一个值 字符
    def gen_check_code(self, weighting_factor, ontology_code, modulus, check_code_dict):
        total = sum(
            int(ontology_code[i]) * weighting_factor[i]
            if ontology_code[i].isdigit()
            else check_code_dict[ontology_code[i]] * weighting_factor[i]
            for i in range(len(ontology_code))
        )
        C9 = modulus - total % modulus
        C9 = 0 if C9 == 31 else C9
        C9 = list(check_code_dict.keys())[list(check_code_dict.values()).index(C9)]
        return C9

    def valid(self, code):
        return code == self.get_social_credit_code(code)


if __name__ == '__main__':
    ci = CreditIdentifier()
    re = ci.gen_random_credit_code()
    print(re)



"""
Name : gm_parse_response_utils.py
Author  : 写上自己的名字
Contact : 邮箱地址
Time    : 2023-05-16 9:33
Desc:  快速解析请求返回text，并获取自己想要的数据。需学习jsonpath插件
"""

import json
from jsonpath import jsonpath

def gm_extract_json(text, jsonpath_expression):
    """使用jsonpath工具类解析请求返回值"""
    try:
        # 判断是否
        if isinstance(text, dict):
            data = jsonpath(text, jsonpath_expression)  # 使用jsonpath进行解析
        elif isinstance(text, str):
            text1 = json.loads(text)
            data = jsonpath(text1, jsonpath_expression)  # 使用jsonpath进行解析
        elif isinstance(text, list):
            data = jsonpath(text, jsonpath_expression)  # 使用jsonpath进行解析
        else:
            json_text = json.loads(text)  # 如果是非dict、str、list类型，则转换成python对象
            data = jsonpath(json_text, jsonpath_expression)  # 使用jsonpath进行解析
        return data
    except TypeError as e:
        print("入参类型：{}，入参数据：{}，请检查错误:{}".format(type(text), text, e))


if __name__ == '__main__':
    s = """{ "store": 
                { "book": 
                    [
                        { "category": "reference", "author": "Nigel Rees", "title": "Sayings of the Century", "price": 8.95 },
                        { "category": "fiction", "author": "Evelyn Waugh", "title": "Sword of Honour", "price": 12.99 }, 
                        { "category": "fiction", "author": "Herman Melville", "title": "Moby Dick", "isbn": "0-553-21311-3", "price": 8.99 }, 
                        { "category": "fiction", "author": "J. R. R. Tolkien", "title": "The Lord of the Rings", "isbn": "0-395-19395-8", "price": 22.99 } 
                    ], 
                "bicycle": { "color": "red", "price": 19.95 } 
                } 
            }"""

    print(gm_extract_json(s, '$.store.book'))
    print(gm_extract_json(s, '$.store.book[0]'))
    print(gm_extract_json(s, '$.store.book[0,3]'))
    print(gm_extract_json(s, '$.store.book[*].author'))
    print(gm_extract_json(s, '$.store.book[(@.length-1)].title'))
    print(gm_extract_json(s, '$.store.book[3].title'))
    print(gm_extract_json(s, '$.store.book[?(@.price<10)].price'))


    print([i*2 for i in gm_extract_json(s, '$.store.book[*].author')])

    d = """{"id": "1251862962956951552"}"""
    print(type(s))
    print(type(d))
    print(gm_extract_json(d, '$.id'))
    package_id = gm_extract_json(d, '$.id')  # 取第一个评标室已结束的packageid
    print(package_id)
    package_room_state = gm_extract_json(d, '$.evaluateRoomState')  # 取第一个评标室已结束的packageid
    print(package_room_state)







"""
Name : gm_sqlconn_utils.py
Author  : 写上自己的名字
Contact : 邮箱地址
Time    : 2021/3/22 15:52
Desc: 操作MYSQL数据库
"""

import pymysql
import pyodbc

# 数据库连接信息
user = "root"
password = "mysql"
# ip地址
env20 = "192.168.2.20"
env15 = "192.168.2.15"

# show环境端口
show_xcj_sql_port = 31004
show_zcj_sql_port = 31404
show_inner_sql_port = 31604
show_analysis_sql_port = 31406

# test1环境和端口
test1_zcj_sql_port = 32404
test1_xcj_sql_port = 32004
test1_inner_sql_port = 32604
test1_syh_sql_port = 32904
test1_analysis_sql_port = 32406

# test2环境端口
test2_jydn_sql_port = 34704
test2_jydw_sql_port = 34804

# 使用15服务器的sql容器
test2_zcj_sql_port = 34404
test2_xcj_sql_port = 34004
test2_inner_sql_port = 34604

# 达梦数据库



class OperateMysql(object):
    """快速连接gmsoft内部测试数据库"""

    def __init__(self, env, host):

        # 账号密码初始化
        self.user = user
        self.password = password
        self.host = host

        # 数据库连接地址初始化, 端口初始化
        if (env == 'test2' and host == 'jydn') or (env == 'test2' and host == 'jydw'):
            # test2特殊处理,军医大内和军医大外使用ip应该是192.168.2.20
            self.env = env20
            self.jydn_port = test2_jydn_sql_port
            self.jydw_port = test2_jydw_sql_port
            try:
                self.jydn_conn = pymysql.connect(host=self.env, user=self.user,
                                                 password=self.password, port=self.jydn_port, charset='utf8mb4')
                self.jydw_conn = pymysql.connect(host=self.env, user=self.user,
                                                 password=self.password, port=self.jydw_port, charset='utf8mb4')
            except TimeoutError as e:
                print('连接超时：{}'.format(e))

            print("已创建jydn数据库连接,链接信息{}:{}".format(self.host, self.jydn_port))
            print("已创建jydw数据库连接,链接信息{}:{}".format(self.host, self.jydw_port))

        elif env == 'test2':
            # test2特殊处理，ip应该是192.168.2.15
            self.env = env15
            self.zcj_port = test2_zcj_sql_port
            self.xcj_port = test2_xcj_sql_port
            self.inner_port = test2_inner_sql_port
            try:
                self.zcj_conn = pymysql.connect(host=self.env, user=self.user,
                                                password=self.password, port=self.zcj_port, charset='utf8mb4')
                self.xcj_conn = pymysql.connect(host=self.env, user=self.user,
                                                password=self.password, port=self.xcj_port, charset='utf8mb4')
                self.inner_conn = pymysql.connect(host=self.env, user=self.user,
                                                  password=self.password, port=self.inner_port, charset='utf8mb4')
            except TimeoutError as e:
                print('连接超时：{}'.format(e))

        elif env == 'show' and host == 'zcj':
            self.env = env20
            self.zcj_port = show_zcj_sql_port
            self.zcj_conn = pymysql.connect(host=self.env, user=self.user, password=self.password, port=self.zcj_port, charset='utf8mb4')
        elif env == 'show' and host == 'xcj':
            self.env = env20
            self.xcj_port = show_xcj_sql_port
            self.xcj_conn = pymysql.connect(host=self.env, user=self.user, password=self.password, port=self.xcj_port, charset='utf8mb4')
        elif env == 'show' and host == 'analysis':
            self.env = env20
            self.analysis_port = show_analysis_sql_port
            self.analysis_conn = pymysql.connect(host=self.env, user=self.user, password=self.password, port=self.analysis_port, charset='utf8mb4')
        elif env == 'test1' and host == 'zcj':
            self.env = env20
            self.zcj_port = test1_zcj_sql_port
            self.zcj_conn = pymysql.connect(host=self.env, user=self.user, password=self.password, port=self.zcj_port, charset='utf8mb4')
        elif env == 'test1' and host == 'xcj':
            self.env = env20
            self.xcj_port = test1_xcj_sql_port
            self.xcj_conn = pymysql.connect(host=self.env, user=self.user, password=self.password, port=self.xcj_port, charset='utf8mb4')
        elif env == 'test1' and host == 'analysis':
            self.env = env20
            self.analysis_port = test1_analysis_sql_port
            self.analysis_conn = pymysql.connect(host=self.env, user=self.user, password=self.password, port=self.analysis_port, charset='utf8mb4')
        else:
            print("未获取到env或host参数")

    def select_first_data(self, sql):
        """
        查询第一条数据
        """
        try:
            # 执行 sql 语句
            if self.host == 'zcj':
                with self.zcj_conn.cursor(pymysql.cursors.DictCursor) as cursor:
                    cursor.execute(sql)
                    first_data = cursor.fetchone()
                    return first_data
            elif self.host == 'xcj':
                with self.xcj_conn.cursor(pymysql.cursors.DictCursor) as cursor:
                    cursor.execute(sql)
                    first_data = cursor.fetchone()
                    return first_data
        finally:
            if hasattr(self, 'xcj_conn'):
                self.xcj_conn.close()
            if hasattr(self, 'zcj_conn'):
                self.zcj_conn.close()
            if hasattr(self, 'analysis_conn'):
                self.analysis_conn.close()

    def select_all_data(self, sql):
        """
        查询所有数据
        :param sql:
        :return:
        """
        try:
            # 执行 sql 语句
            if self.host == 'zcj':
                with self.zcj_conn.cursor(pymysql.cursors.DictCursor) as cursor:
                    cursor.execute(sql)
                    first_data = cursor.fetchall()
                    return first_data
            elif self.host == 'xcj':
                with self.xcj_conn.cursor(pymysql.cursors.DictCursor) as cursor:
                    cursor.execute(sql)
                    first_data = cursor.fetchall()
                    return first_data
        finally:
            if hasattr(self, 'xcj_conn'):
                self.xcj_conn.close()
            if hasattr(self, 'zcj_conn'):
                self.zcj_conn.close()
            if hasattr(self, 'analysis_conn'):
                self.analysis_conn.close()



    def delete_data(self, host, sql):
        """
        查询所有数据
        :param host:  zcj、xcj
        :param sql: SQL查询
        :return:
        """
        try:
            if host == 'zcj':
                self.zcj_cursor.execute(sql)
                self.zcj_cursor.commit()
            elif host == 'xcj':
                self.xcj_cursor.execute(sql)
                self.xcj_cursor.commit()

        except TypeError as e1:
            print("SQL执行时类型错误！请检查" % e1)
            self.zcj_cursor.rollback()  # 回滚操作
            self.xcj_cursor.rollback()  # 回滚操作
        except Exception as e2:
            print("执行sql异常:%s" % e2)
            self.zcj_cursor.rollback()  # 回滚操作
            self.xcj_cursor.rollback()  # 回滚操作
        finally:
            if hasattr(self, 'xcj_conn'):
                self.xcj_conn.close()
            if hasattr(self, 'zcj_conn'):
                self.zcj_conn.close()
            if hasattr(self, 'analysis_conn'):
                self.analysis_conn.close()

    def conn_close(self):
        # 关闭数据库连接
        try:
            if hasattr(self, 'xcj_conn'):
                self.xcj_conn.close()
            if hasattr(self, 'zcj_conn'):
                self.zcj_conn.close()
            if hasattr(self, 'jydn_conn'):
                self.jydn_conn.close()
            if hasattr(self, 'jydw_conn'):
                self.jydw_conn.close()
            if hasattr(self, 'syh_conn'):
                self.syh_conn.close()
            if hasattr(self, 'inner_conn'):
                self.inner_conn.close()
            if hasattr(self, 'xcj_cursor'):
                self.xcj_cursor.close()
            if hasattr(self, 'zcj_cursor'):
                self.zcj_cursor.close()
            if hasattr(self, 'jydn_cursor'):
                self.jydn_cursor.close()
            if hasattr(self, 'jydw_cursor'):
                self.jydw_cursor.close()
            if hasattr(self, 'syh_cursor'):
                self.syh_cursor.close()
            if hasattr(self, 'inner_cursor'):
                self.inner_cursor.close()
        except AttributeError as e:
            print("数据库连接已关闭!!!")


class DMSql(object):

    def __init__(self):
        CONN_STR = (
            r'DRIVER={DM8 ODBC DRIVER};'
            r'SERVER=192.168.2.32:34994;'  # 服务器地址
            r'DATABASE=DJC_EXPERT;'  # 数据库名
            r'UID=djc_expert;'  # 用户名
            r'PWD=111111111;'  # 密码
        )
        self.conn = pyodbc.connect(CONN_STR)
        self.cursor = self.conn.cursor()

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        self.conn.close()
        print('关闭达梦数据库连接！！！')

    def query(self, sql: str, params=None):
        try:
            self.cursor.execute(sql, params)
            result = self.cursor.fetchall()
            return result
        except Exception as e:
            print(f"An error occurred:{e}")
            return []

    def delete(self, sql):
        try:
            self.cursor.execute(sql)
            self.cursor.commit()
            # result = self.cursor.fetchone()
            # return result
        except Exception as e:
            print(f"An error occurred:{e}")
            return []

    def update(self, sql):
        try:
            self.cursor.execute(sql)
            self.cursor.commit()
            # result = self.cursor.fetchone()
            # return result
        except Exception as e:
            print(f"An error occurred:{e}")
            return []

    def count(self, sql):
        try:
            self.cursor.execute(sql)
            result = self.cursor.fetchall()
            if len(result) == 1 and len(result[0]) == 1:
            # 如果结果集只有一个元素，返回那个元素
                return result[0][0]
        except Exception as e:
            print(f"An error occurred:{e}")
            return []


if __name__ == "__main__":
    om = OperateMysql('test1', 'zcj')
    apply_list = om.select_all_data('select s.id, s.CREATE_AREA_ID, s.CREATE_AREA_NAME, s.EVALUATE_STATE, s.SECRET_DATE, s.CREATE_ORG_ID from djc_expert.apply s;')




"""
Name : gm_demo_project.py
Author  : 写上自己的名字
Contact : 邮箱地址
Time    : 2023-11-15 10:13
Desc:
"""

def gm_verify_true(mylist):
	my_result = all(mylist)
	return my_result

def gm_verify_any(mylist):
	my_result = any(mylist)
	return my_result


if __name__ == '__main__':
	print(gm_verify_true([False, '2']))
	print(gm_verify_any([False, '2']))





"""
Name : run.py.py
Author  : 写上自己的名字
Contact : 邮箱地址
Time    : 2024-02-19 10:10
Desc:
"""

from  gm_yaml_process_utils import read_yaml,read_data_yaml

if __name__ == '__main__':
    d = read_yaml('data', 're_guarantee', 'data_common_record.yaml')
    print(d)


"""
Name : gm_randomdata_utils.py
Author  : 写上自己的名字
Contact : 邮箱地址
Time    : 2023-02-13 10:11
Desc: 生成随机数据，如手机号、身份证号、企业信息等
"""

"""
Name : gm_randomdata_utils.py
Author  : 粟飞
Contact : 邮箱地址
Time    : 2022-09-01 13:46
Desc: 生成各种测试数据
"""

from faker import Factory
import time

fake = Factory().create('zh_CN')

def getMobile():
    '''随机手机号'''
    return fake.phone_number()

def getName():
    """随机姓名"""
    return fake.name()

def getAddress():
    """随机地址"""
    return fake.address()

def getEmail():
    """随机email"""
    return fake.email()

def getCompany():
    """随机公司名"""
    return fake.company()

def getCompanySuffix():
    return fake.company_suffix()

def getCity():
    """城市名，带市/县"""
    return fake.city()

def getCityName():
    """城市名，不带市/县"""
    return fake.city_name()

def getProvice():
    """省份"""
    return fake.province()

def getIDcard():
    """身份证号"""
    return fake.ssn()


def getProfile():
    """生成一串用户数据"""
    return fake.profile()

def getInt(min_value=0, max_value=10000, step=1):
    """生成长度在min_chars到max_chars之间整数"""
    return fake.pyint(min_value=min_value, max_value=max_value, step=step)

def getFloat(min_value=0, max_value=10000, step=1):
    """生成长度在min_chars到max_chars之间的浮点数"""
    return fake.pyint(min_value=min_value, max_value=max_value, step=step)

def getStr(min_chars=None, max_chars=2000):
    """生成长度在min_chars到max_chars之间的字符串
    :param min_chars:
    :param max_chars:
    :return:
    """
    return fake.pystr(min_chars=min_chars, max_chars=max_chars)

def getLinuxTimestamp(t=1):
    """获取当前linux时间戳"""
    if t == 1:
        st = round(time.time()*1000)
    return st


if __name__ == '__main__':
    print(getMobile())
    print(getCityName())
    print(getInt(1, 500000))
    print(getCompany())
    print(getProfile())
    print(getIDcard())
    print(getLinuxTimestamp())
    print(getStr(200))
    print(getProfile())
    print(getProfile()['name'])



"""
Name : gm_yaml_process_utils.py
Author  : 写上自己的名字
Contact : 邮箱地址
Time    : 2023-05-16 14:42
Desc: yaml读取封装
"""


import yaml
import os
import sys

# 读取yaml文件
def read_yaml(*filename):
    """
    读取yaml
    :param
    :return:
    """
    # 文件夹地址, 获取配置文件的全路径,兼容linux和windows
    ROOT_DIR = os.path.dirname(os.path.dirname(os.path.abspath(os.getcwd())))
    yaml_path = os.sep.join([ROOT_DIR])
    for i in range(len(filename)):
        yaml_path = os.sep.join([yaml_path, filename[i]])
    if not os.path.exists(yaml_path):  # 不存在则只退回一级
        ROOT_DIR = os.path.dirname(os.path.abspath(os.getcwd()))
        yaml_path = os.sep.join([ROOT_DIR])
        for i in range(len(filename)):
            yaml_path = os.sep.join([yaml_path, filename[i]])
        if not os.path.exists(yaml_path):  # 不存在则标识为根目录
            ROOT_DIR = os.path.abspath(os.getcwd())
            yaml_path = os.sep.join([ROOT_DIR])
            for i in range(len(filename)):
                yaml_path = os.sep.join([yaml_path, filename[i]])
    try:
    # 处理配置文件中含中文出现乱码，需加入encoding='utf-8'，
        with open(yaml_path, 'r', encoding='utf-8') as f:
            x = yaml.load(f, Loader=yaml.FullLoader)
            return x
    except FileNotFoundError as e:
        print("file not found!!! {}".format(e))
    except TypeError as t:
        print("the type of file is wrong!!! {}".format(t))


def read_data_yaml(*filename):
    """
    读取数据yaml
    :param
    :return:
    """
    # 文件夹地址
    # yaml_directory_path = os.path.abspath(os.path.dirname(os.path.dirname(__file__)))
    # 获取配置文件的全路径,兼容linux和windows

    ROOT_DIR = os.path.dirname(os.path.dirname(os.path.abspath(os.getcwd())))
    yaml_path = os.sep.join([ROOT_DIR])
    for i in range(len(filename)):
        yaml_path = os.sep.join([yaml_path, filename[i]])

    if not os.path.exists(yaml_path):  # 不存在则只退回一级
        ROOT_DIR = os.path.dirname(os.path.abspath(os.getcwd()))
        yaml_path = os.sep.join([ROOT_DIR])
        for i in range(len(filename)):
            yaml_path = os.sep.join([yaml_path, filename[i]])
        if not os.path.exists(yaml_path):  # 不存在则标识为根目录
            ROOT_DIR = os.path.abspath(os.getcwd())
            yaml_path = os.sep.join([ROOT_DIR])
            for i in range(len(filename)):
                yaml_path = os.sep.join([yaml_path, filename[i]])
    try:
        # 处理配置文件中含中文出现乱码，需加入encoding='utf-8'
        with open(yaml_path, 'r', encoding='utf-8') as f:
            x = yaml.load(f, Loader=yaml.FullLoader)
            return x
    except FileNotFoundError as e:
        print("file not found!!! {}".format(e))
    except TypeError as t:
        print("the type of file is wrong!!! {}".format(t))


if __name__ == "__main__":
    a = read_yaml('data', 'xcj', 'data_common_record.yaml')
    s = read_data_yaml('data', 're_guarantee', 'data_common_record.yaml')
    print(a)
    print(s)




"""
Name : gm_login_utils.py
Author  : 池泽琴
Contact : 邮箱地址
Time    : 2023-10-07 14:36
Desc:
"""
import hashlib
import json
import requests
from gmmysql.mysqlexe import OperateMysql


def login_xcj(request, user_name, password="GmsoftTest_1997"):
    client_id = 'plat@DJC'
    plat_name = "行采平台"
    login(request, plat_name, client_id, user_name, password)


def login_zcj(request, user_name, password="GmsoftTest_1997"):
    client_id = 'plat@ZCJ'
    plat_name = "政采平台"
    login(request, plat_name, client_id, user_name, password)


def login(request, plat_name, client_id, user_name, password="GmsoftTest_1997"):
    djc_domain_name, xcj_domain_name, zcj_domain_name, zc_domain_name, jc_domain_name, zcj_pm_domain_name \
        = get_domain_name(request)
    domain_name = djc_domain_name
    # print(domain_name)

    # 认证中心登录
    auth_url = "https://" + domain_name + "/djc-gateway/authing/login"
    redirect_url = "https://" + domain_name + "/gateway/v1/login"
    origin = "https://" + domain_name
    r = requests.session()
    login_auth(r, auth_url, redirect_url, client_id, domain_name, origin, user_name, password, plat_name)

    # 平台登录
    login_url = "https://" + domain_name + "/djc-gateway/authing/oauth/authorize"
    client_id_secret = __get_client_id_secret(client_id)
    access_token = login_plat(r, client_id, client_id_secret, domain_name, login_url, redirect_url, plat_name)
    return access_token


def login_auth(r, auth_url, redirect_url, client_id, scope, origin, username, password, auth_name):
    # 认证中心登录
    md5 = hashlib.md5()
    md5.update(str(password).encode('utf-8'))
    password1 = md5.hexdigest()
    headers = {
        "Accept": "application/json",
        "Content-Type": "application/x-www-form-urlencoded"
    }

    success_uri = "https://" + scope + "/login-app/login-success/index.html"
    if client_id == "cqzcy" or client_id == "cqzbj":
        success_uri = ""

    data = {
        "password": password1,
        "username": username,
        "origin": origin,
        "client_id": client_id,
        "scope": scope,
        "options": '',
        "response_type": 'code',
        "redirect_uri": redirect_url,
        "success_uri": success_uri,
        "state": '{"client_id": "' + client_id + '","scope":"' + scope + '","redirect_uri":"' + redirect_url + '"}'
    }
    # if code != '':
    #     data.update(code=code, mobile=mobile)
    # 认证中心登录 verify="GMDEVSERVER-CA.cer"
    login_res = r.post(auth_url, data=data, headers=headers, verify=False)
    # print(login_res.headers['Set-Cookie'])
    print("\n"+auth_name+"认证中心登录结果-Response code是: {}".format(login_res.status_code))

    if login_res.status_code == 400 and login_res.text.find('"message":"请进行二次验证"') >= 0:
        # 需做二次验证
        code = "111111"
        print(login_res.text)
        check_mobile = json.loads(login_res.text)["additional"]["mobile"]
        data.update(code=code, mobile=check_mobile)
        login_res = r.post(auth_url, data=data, headers=headers, verify=False)
        print("\n" + auth_name + "认证中心登录结果-Response code是: {}".format(login_res.status_code))
        # login_auth(r, auth_url, redirect_url, client_id, scope, username, password, "111111", check_mobile, auth_name)
    elif login_res.status_code == 403 and login_res.text.find('拒绝访问') >= 0:
        # 需做极验证
        print(login_res.text)
        auth_url = auth_url + "?geetest_challenge=111111&geetest_seccode=111111&geetest_validate=111111"
        login_res = r.post(auth_url, data=data, headers=headers, verify=False)
        print("\n" + auth_name + "登录结果-Response code是: {}".format(login_res.status_code))
        # print("czq:"+login_res.text)

    if login_res.status_code == 200:
        # 同步登录相关认证中心
        location_url = json.loads(login_res.text)['location']
        grant_res = r.get(location_url, verify=False)
        print("location请求结果-Response code是: {}".format(grant_res.status_code))
    return login_res


def login_plat(r, client_id, client_id_secret, scope, login_url, redirect_url, plat_name):
    # 平台登录
    authorize_params = {
        'response_type': 'code',
        'client_id': client_id,
        'redirect_uri': redirect_url,
        'scope': scope,
        'options': '',
        "state": '{"client_id": "' + client_id + '","scope":"' + scope + '","redirect_uri":"' + redirect_url + '"}'
    }
    # print(authorize_params)
    # 询问认证中心xx平台能否登录
    authorize_res = r.get(login_url, params=authorize_params, verify=False, allow_redirects=False)
    # print(authorize_res.status_code)
    # print(authorize_res.text)
    if authorize_res.status_code == 302:
        # print(authorize_res.headers['location'].find("code="))
        if authorize_res.headers['location'].find("code=") >= 0:
            code = authorize_res.headers['location'].split('code=')[1].split('&')[0]
            print("code：{}".format(code))

            _headers = {
                "Authorization": "Basic "+client_id_secret,
                "Content-Type": "application/x-www-form-urlencoded"
            }
            login_params = {
                'code': code,
                'grant_type': 'authorization_code',
                "redirect_uri": redirect_url
            }
            # print(login_params)
            # print(redirect_url)
            login_plat_res = r.get(login_url.replace("authorize", "token"), params=login_params,
                                   verify=False, headers=_headers)
            # print(login_plat_res.text)
            # print(login_plat_res.headers['Set-Cookie'])
            print(plat_name + "平台登录结果-Response code是：{}".format(login_plat_res.status_code))
            # print("请求结果：{}".format(login_plat_res.text))
            access_token = login_plat_res.text.split('":"')[1].split('","')[0]
            print("access_token：{}".format(access_token))
            return access_token
        else:
            return authorize_res.headers['location']
    else:
        return authorize_res.text


def reset_pwd(mobile):
    # 固定盐值
    fix_Salt_Value = "2314861a-301c-403a-b4c9-5b1734101043"
    pwd = "GmsoftTest_1997"
    sql = "UPDATE logincomm.`TL_Account` " \
          "SET `Passwd`=MD5(CONCAT(MD5('" + pwd + "'),'" + fix_Salt_Value + "')),`nonce` = '' " \
          "WHERE `MOBILE`='" + mobile + "'"
    om = OperateMysql()
    print("\n"+sql)
    om.delete_data(sql)


def get_domain_name(request):
    # 获取域名
    # login_env:1-Test环境、2-Test1环境、3-show环境、4-# 正式环境、5-Dev1环境、6-Test2
    login_env = request.config.getoption("--env")
    if login_env == "test1":
        djc_domain_name = "www.djctest1.gm"
        xcj_domain_name = "www.xcjtest1.gm"
        zcj_domain_name = "www.cqzcjtest1.gm"
        zc_domain_name = "www.zctest1.gm"
        jc_domain_name = "www.jctest1.gm"
        zcj_pm_domain_name = "192.168.2.22:31880"
    elif login_env == "show":
        djc_domain_name = "www.djcshow.gm"
        xcj_domain_name = "www.cqzcjshow.com"
        zcj_domain_name = "www.gpwbeta.com"
        zc_domain_name = "www.zcshow.gm"
        jc_domain_name = "www.jcshow.gm"
        zcj_pm_domain_name = "192.168.2.20:31880"
    elif login_env == "test2":
        djc_domain_name = "www.djctest2.gm"
        xcj_domain_name = "www.xcjtest2.gm"
        zcj_domain_name = "www.cqzcjtest2.gm"
        zc_domain_name = "www.zctest2.gm"
        jc_domain_name = "www.jctest2.gm"
        zcj_pm_domain_name = "192.168.2.22:31880"
    else:
        djc_domain_name = "www.djcdev1.gm"
        xcj_domain_name = "www.xcjdev1.gm"
        zcj_domain_name = "www.cqzcjdev1.gm"
        zc_domain_name = "www.zcdev1.gm"
        jc_domain_name = "gpw.xcj360.com:21880"
        zcj_pm_domain_name = "192.168.2.21:31880"
    return djc_domain_name, xcj_domain_name, zcj_domain_name, zc_domain_name, jc_domain_name, zcj_pm_domain_name


def __get_client_id_secret(client_id='plat@XCJ'):
    # 获取client_id_secret
    if client_id == 'plat@XCJ':
        # plat@XCJ:test的BASE64编码是cGxhdEBYQ0o6dGVzdA==,前面的test是取的application.yml文件中security.user.password
        client_id_secret = 'cGxhdEBYQ0o6dGVzdA=='
    elif client_id == 'plat@DJC':
        # plat@DJC:test的BASE64编码是cGxhdEBESkM6dGVzdA==,前面的test是取的application.yml文件中security.user.password
        client_id_secret = 'cGxhdEBESkM6dGVzdA=='
    else:
        # plat@ZCJ:test的BASE64编码是cGxhdEBaQ0o6dGVzdA==,前面的test是取的application.yml文件中security.user.password
        client_id_secret = 'cGxhdEBaQ0o6dGVzdA=='
    return client_id_secret


if __name__ == '__main__':
    login_xcj("test1", "admin")



from openpyxl import load_workbook, Workbook
import os

'''
@time: 2019-01-12
@auth: fs@file: ParseExcel.py
@IDE: pycharm
'''


class ReadExcel:
    def __init__(self, *filename):
        """获取api测试用例excel文件地址,当前是././mock_data/XXX.xlsx文件"""
        ROOT_DIR = os.path.dirname(os.path.dirname(os.path.abspath(os.getcwd())))
        self.excel_path = os.path.join(ROOT_DIR, *filename)
        print(f"读取excel文件路径：{self.excel_path}")
        if not os.path.exists(self.excel_path):  # 不存在则只退回一级
            ROOT_DIR = os.path.dirname(os.path.abspath(os.getcwd()))
            self.excel_path = os.sep.join([ROOT_DIR])
            for i in range(len(filename)):
                self.excel_path = os.sep.join([self.excel_path, filename[i]])
            if not os.path.exists(self.excel_path):  # 不存在则标识为根目录
                ROOT_DIR = os.path.abspath(os.getcwd())
                self.excel_path = os.sep.join([ROOT_DIR])
                for i in range(len(filename)):
                    self.excel_path = os.sep.join([self.excel_path, filename[i]])

    def read_excel_data(self, *sheet_name):
        """调用AnalysisExcel类的方法解析excel数据"""
        excel = AnalysisExcel(self.excel_path)
        print(self.excel_path)
        try:
            for i in range(len(sheet_name)):
                sheet = excel.get_sheet_by_name(sheet_name[i])
                test_data = excel.get_all_values_of_sheet(sheet)
        finally:
            excel.close()
        return test_data


class AnalysisExcel:
    def __init__(self, excel_path):
        """读取excel文件"""
        self.wk = load_workbook(excel_path)
        self.excelFile = excel_path

    def get_sheet_by_name(self, sheet_name):
        """获取excel的sheet对象"""
        sheet = self.wk[sheet_name]
        return sheet

    @staticmethod
    def get_row_num(sheet):
        """获取有效数据的最大行号"""
        return sheet.max_row

    @staticmethod
    def get_cols_num(sheet):
        """获取有效数据的最大列号"""
        return sheet.max_column

    def get_row_values(self, sheet, row_num):
        """获取某一行的数据"""
        max_row_num = self.get_cols_num(sheet)
        row_values = []
        for cols_num in range(1, max_row_num + 1):
            value = sheet.cell(row_num, cols_num).value
            if value is None:
                value = ''
            row_values.append(value)
        return tuple(row_values)

    def get_col_value(self, sheet, column_num):
        """获取某一列的数据"""
        max_row_num = self.get_row_num(sheet)
        column_values = []
        for row in range(2, max_row_num+1):
            value = sheet.cell(row, column_num).value
            if value is None:
                value = ''
            column_values.append(value)
        return tuple(column_values)

    def get_value_of_cell(self, sheet, row_num, column_num):
        value = sheet.cell(row_num, column_num).value
        if value is None:
            value = ''
        return value

    def get_all_values_of_sheet(self, sheet):
        """获取某一个sheet页的所有测试数据，返回一个元祖组成的列表"""
        max_row_num = self.get_row_num(sheet)
        column_num = self.get_cols_num(sheet)
        all_values = []
        for row in range(2, max_row_num + 1):
            row_values = []
            for column in range(1, column_num + 1):
                value = sheet.cell(row, column).value
                if value is None:
                    value = ''
                row_values.append(value)
            all_values.append(tuple(row_values))
        return all_values

    def close(self):
        self.wk.close()


class WriteExcel:
    def __init__(self, file_name):
        """获取api测试用例excel文件地址,当前是././mock_data/XXX.xlsx文件"""
        self.case_file_path = os.path.abspath(os.path.dirname(os.path.dirname(__file__)))
        self.case_file_dir = os.path.join(self.case_file_path + '\\', 'mock_data\\' + file_name)

    # 新建excel
    def creatwb(self):
        wb = Workbook()
        wb.save(filename=self.case_file_dir)
        print("新建Excel：" + self.case_file_dir + "成功")

    # 写入excel文件中 date 数据，date是list数据类型， fields 表头
    def savetoexcel(self, data, fields, sheetname):
        print("写入excel")
        wb = load_workbook(filename=self.case_file_dir)

        sheet = wb.active
        sheet.title = sheetname

        field = 1
        for field in range(1, len(fields) + 1):  # 写入表头
            sheet.cell(row=1, column=field, value=str(fields[field - 1]))

        row1 = 1
        col1 = 0
        for row1 in range(2, len(data) + 2):  # 写入数据
            for col1 in range(1, len(data[row1 - 2]) + 1):
                sheet.cell(row=row1, column=col1, value=str(data[row1 - 2][col1 - 1]))
                print("当前是第{}行，第{}列，数据是{}".format(row1, col1, str(data[row1 - 2][col1 - 1])))
        print(len(data))
        wb.save(filename=self.case_file_dir)


if __name__ == '__main__':
    # file_path = os.sep.join(['data', 'xcj', 'Itemexcutebid', '直接录入采购结果.xlsx'])  # 拼接xlsx完整路径
    rd = ReadExcel('data', 'xcj', '报表数据源1.xlsx').read_excel_data('refresh_put')
    # a = rd.read_excel_data('create')
    print(rd)



"""
Name : stock_enum.py
Author  : 写上自己的名字
Contact : 邮箱地址
Time    : 2023-05-11 15:14
Desc: 采购数据枚举类
"""
import json
from enum import Enum


# 采购枚举
class StockEnum(Enum):
    """采购数据枚举，来源于码表"""
    ITEMTYPE = 301  # 项目类型
    STOCKORGANFORMS = 302  # 采购组织形式
    COMMIT = 302  # 自行或委托
    STOCKMODE = 304  # 采购方式
    STOCKCATATYPE = 305  # 采购目录分类
    ORIGINTYPE = 307   # 是否进口商品
    BRANDTYPE = 308  # 品目类别
    FINANCEKIND = 310  # 资金性质
    PAYCHANNEL = 311  # 支付渠道
    FINANCCATAGORY = 312   # 资金类别
    SERVERCATEGORY = 313  # 服务类别
    ACCOUNT = 314  # 管理账号
    UNIT = 321  # 计量单位
    GOODS = '货物类'
    ENGINEERING = '工程类'
    SERVICES = '服务类'


class EOpenBidHallEnum(Enum):
    CHOOSEEVAL = 37
    CHOOSEOPENBID = 36


"""
Name : gm_assert_utils.py
Author  : 写上自己的名字
Contact : 邮箱地址
Time    : 2023-05-20 16:46
Desc: 验证assert封装
"""
import pytest

EQUALTYPENOTICE = "两个值不相等，注意类型是否一致！！！"
NOTEQUALTYPENOTICE = "两个值相等，注意类型是否一致！！！"
INCLUDENOTICE = "第一个值不在第二个值内，请检查！"
NOINCLUDENOTICE = "第一个值在第二个值内，请检查！"
CODENOTICE = "请求期望CODE与返回CODE不一致，请检查！"

def gm_assert_equal(first_value, second_value, types):
    """验证是否相等"""
    try:
        first = _convert_type(first_value, to_type=types)
        second = _convert_type(second_value, to_type=types)
        assert first == second, EQUALTYPENOTICE
    except AssertionError as e:
        raise AssertionError(e)

def gm_assert_in(first_value, second_value, types, include_notice=INCLUDENOTICE):
    """验证第一个值包含在第二个值内"""
    try:
        first = _convert_type(first_value, to_type=types)
        second = _convert_type(second_value, to_type=types)
        assert first in second, include_notice
        return True
    except AssertionError as e:
        return False


def gm_assert_list_anyone_in(first_value, second_value, types):
    """第一个列表中分别取值并和第二个值验证"""
    try:
        if isinstance(first_value, int):
            if isinstance(second_value, list):
                for value in second_value:
                    second = _convert_type(value, to_type=types)
                    if first_value == second:
                        assert first_value == second, INCLUDENOTICE
                        break
                else:
                    raise AssertionError("None of the elements in the list matched the second_value")
            else:
                second = _convert_type(second_value, to_type=types)
                assert first_value == second, INCLUDENOTICE
        else:
            try:
                iter(first_value)
            except TypeError:
                raise AssertionError("The list is not iterable")
            else:
                all_item_not_in_second = True
                for i in first_value:
                    first = _convert_type(i, to_type=types)
                    second = _convert_type(second_value, to_type=types)
                    if first in second:
                        all_item_not_in_second = False
                        break
                if all_item_not_in_second:
                    raise AssertionError("it is not found, None of the elements in the list matched the second_value")

    except AssertionError as e:
        raise AssertionError(e)

def gm_assert_not_in(first_value, second_value, types):
    """验证第一个值不包含在第二个值内"""
    try:
        first = _convert_type(first_value, to_type=types)
        second = _convert_type(second_value, to_type=types)
        assert first not in second, NOINCLUDENOTICE
    except AssertionError as e:
        raise AssertionError(e)

def gm_assert_not_equal(first_value, second_value, types):
    """验证不相等"""
    try:
        first = _convert_type(first_value, to_type=types)
        second = _convert_type(second_value, to_type=types)
        assert first != second, NOTEQUALTYPENOTICE
    except AssertionError as e:
        raise AssertionError(e)

def gm_assert_response_code(first_value, second_value, types):
    """验证response的code值"""
    try:
        first = _convert_type(first_value, to_type=types)
        second = _convert_type(second_value, to_type=types)
        print('多数据验证')
        assert first == second, CODENOTICE
    except AssertionError as e:
        raise AssertionError(e)

def gm_assert_multiple_values_equal(values):
    """多数据验证相等"""
    assert len(values) > 1, "At least two values are needed"
    for i in range(0, len(values)):
        values[i] = _convert_type(values[i])
        print(values[i])
        assert values[i] == values[0], f"第{i+1}个数的Value {values[i]} does not equal {values[0]}"

def gm_assert_lists_iseuqals(list1, list2):
    """验证两个列表的长度是否相等，并分别对比两个列表相同Index的值是否相等"""
    assert len(list1) == len(list2)
    for i in range(len(list1)):
        print(list1[i], list2[i])
        assert list1[i] == list2[i], f"列表List1的第{i+1}个数的Value {list1[i]} != 列表List2的第{i+1}个数的Value {list2[i]}"



def gm_assert_lists_isinclude(list1, list2, reverse=False):
    """验证列表的值是否在另一列表"""
    if reverse is False:
        for i in range(len(list2)):
            print(list2[i])
            assert list2[i] in list1, f"列表2的第{i + 1}个数的值：{list2[i]}   在列表1不存在"
    else:
        for i in range(len(list1)):
            assert list1[i] in list2, f"列表1的第{i + 1}个数的值：{list1[i]}   在列表2不存在"

def _convert_type(value, to_type=str, default=None):
    try:
        return to_type(value)
    except (ValueError, TypeError):
        return default

def gm_assert_dict_iseuqal(dict1, dict2):
    """验证两个字典的长度是否相等，并分别对比两个字典相同Index的值是否相等"""
    assert len(dict1) == len(dict2)
    for k in dict1.keys():
        print(dict1[k], dict2[k])
        assert str(dict1[k]) == str(dict2[k]), f"字典1的键{k}的Value {dict1[k]} != 字典2的键{k}的Value {dict2[k]}"

def gm_assert_dict_or_list_iseuqal(data1, data2):
    """如果是字典，先转list，如果直接传入List，先比较长度，然后将值转成str类型后，再比较每个值"""
    if isinstance(data1, dict):
        list1 = [str(i) for i in data1.values()]
        list2 = [str(i) for i in data2.values()]
        assert len(list1) == len(list2)
        assert list1 == list2
    elif isinstance(data1, list):
        assert len(data1) == len(data2)
        for dict1, dict2 in zip(data1, data2):
            assert {str(v) for k, v in dict1.items()} == {str(v) for k, v in dict2.items()}
    else:
        print("类型错误，非dict或list类型")


if __name__ == '__main__':
    # first_value = [{'id': '204113', 'orgName': '重庆传办姐家有限责任公司'}, {'id': '20160328162700025', 'orgName': '重庆市重庆市土族龙族采购中心76'}, {'id': '20151223016', 'orgName': '重庆梁平区化中林五有限责任公司'}, {'id': '427750', 'orgName': '重庆重庆市技卡商云有限责任公司'}, {'id': '130117356536988556', 'orgName': '重庆市政府采购中心'}]
    # second_value = [{'id': 204113, 'orgName': '重庆传办姐家有限责任公司'}, {'id': 20160328162700025, 'orgName': '重庆市重庆市土族龙族采购中心76'}, {'id': 20151223016, 'orgName': '重庆梁平区化中林五有限责任公司'}, {'id': 427750, 'orgName': '重庆重庆市技卡商云有限责任公司'}, {'id': 130117356536988556, 'orgName': '重庆市政府采购中心'}]
    # gm_assert_dict_or_list_iseuqal(first_value, second_value)
    # gm_assert_list_anyone_in(400, [400, 401], int)
    s = gm_assert_in('1', '1', str)
    print(s)
    print(gm_assert_in('1', '2', str))
    if gm_assert_in('1', '2', str):
        print("pass")
    else:
        print("error")
    if gm_assert_in('1', '1', str):
        print("pass1111")
    else:
        print("error2222")


"""
Name : gm_timestamp_utils.py
Author  : 写上自己的名字
Contact : 邮箱地址
Time    : 2023-05-16 9:45
Desc:
"""

"""
Name : timestamphandler.py
Author  : 写上自己的名字
Contact : 邮箱地址
Time    : 2021/3/25 10:27
Desc: 根据调用时间，生成时间戳，精确到毫秒
"""

# 年-月-日 时:分:秒
import datetime
import time

nowTime = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
# 年-月-日
dayTime = datetime.datetime.now().strftime('%Y-%m-%d')
# 时:分:秒
hourTime = datetime.datetime.now().strftime('%H:%M:%S.%f')
file_name = datetime.datetime.now().strftime('%Y%m%d%H%M%S%f')


def create_current_timestamp_filename(name, file_format):
    """生成当前时间的文件名
    :param name: 文件名
    :param file_format:  当前时间戳
    :return:
    """
    create_time = datetime.datetime.now().strftime('%Y%m%d%H%M%S%f')
    my_file_name = name + "_" + create_time + file_format
    return my_file_name


def now_timestamp():
    create_time = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S.%f')
    return create_time

def today_start_timestamp():
    """获取调用时间当天0点的时间戳"""
    day_time = int(
        round(
            time.mktime(
                datetime.date.today().timetuple())) *
        1000)
    return day_time

def today_end_timestamp():
    """获取调用时间当天23点59分59秒的时间戳"""
    now = datetime.datetime.now()
    # 今天0点
    zerotoday = now - datetime.timedelta(hours=now.hour,
                                         minutes=now.minute,
                                         seconds=now.second,
                                         microseconds=now.microsecond)
    # 偏移23:59:59
    lasttoday = zerotoday + \
                datetime.timedelta(hours=23, minutes=59, seconds=59)
    # 解析为unix时间戳
    todayend = int(round(time.mktime(lasttoday.timetuple())) * 1000)
    return todayend


#
def after_timestamp(n):
    """获取n天后23小时59分59秒时间戳"""
    hours = int((n + 1) * 24) - 1
    now = datetime.datetime.now()
    zerotoday = now - datetime.timedelta(hours=now.hour,
                                         minutes=now.minute,
                                         seconds=now.second,
                                         microseconds=now.microsecond)
    dd = zerotoday + datetime.timedelta(hours=hours, minutes=59, seconds=59)
    aftertimestemp = int(round(time.mktime(dd.timetuple())) * 1000)
    # 返回第n天后0点时间戳
    return aftertimestemp


def get_current_year_first_day_timestatmp():
    """获取本年度第1天0点的时间戳"""
    now = datetime.datetime.now()
    dd = datetime.datetime(now.year, 1, 1)
    firstdaytimestamp = int(round(time.mktime(dd.timetuple())) * 1000)
    # 返回第n天后0点时间戳
    return firstdaytimestamp


if __name__ == '__main__':
    print(today_start_timestamp())
    print(after_timestamp(3))
    print(create_current_timestamp_filename('hello', '.txt'))



"""
Name : gm_demo.py.py
Author  : 写上自己的名字
Contact : 邮箱地址
Time    : 2023-12-07 16:08
Desc:
"""

def my_add(int1, int2):
	result = int1 + int2
	return result


if __name__ == '__main__':
	print(f"相加结果是：{my_add(1, 5)}")

